asr.test.test\_core
===================

.. automodule:: asr.test.test_core

   
   
   .. rubric:: Functions

   
   .. autofunction:: recipe
   .. autofunction:: test_core
   .. autofunction:: test_recipe_defaults
   .. autofunction:: test_recipe_setting_new_defaults
   .. autofunction:: test_recipe_setting_overriding_defaults
   
   

   
   
   

   
   
   